@@ -103,6 +103,7 @@
 // Code generated by software.amazon.smithy.rust.codegen.smithy-rs. DO NOT EDIT.
 pub use error_meta::Error;
 
+#[doc(inline)]
 pub use config::Config;
 
 mod aws_endpoint;
@@ -134,10 +135,10 @@ pub mod output;
 pub mod paginator;
 /// Crate version number.
 pub static PKG_VERSION: &str = env!("CARGO_PKG_VERSION");
-pub use aws_smithy_http::byte_stream::ByteStream;
-pub use aws_smithy_http::result::SdkError;
-pub use aws_smithy_types::Blob;
-pub use aws_smithy_types::DateTime;
+/// Re-exported types from supporting crates.
+pub mod types {
+    pub use aws_smithy_http::result::SdkError;
+}
 static API_METADATA: aws_http::user_agent::ApiMetadata =
     aws_http::user_agent::ApiMetadata::new("codestarconnections", PKG_VERSION);
 pub use aws_smithy_http::endpoint::Endpoint;
@@ -145,4 +146,5 @@ pub use aws_smithy_types::retry::RetryConfig;
 pub use aws_types::app_name::AppName;
 pub use aws_types::region::Region;
 pub use aws_types::Credentials;
+#[doc(inline)]
 pub use client::Client;
